@@ -97,8 +97,7 @@ def rm_server_redis(clean=False):
 
 def server_mongo(card='lo'):
     """
-    @note, by default, mongodb bind 0.0.0.0, so we bind
-    only support 64-bit system
+    @note this mongo only support 64-bit system
     :return:
     """
 
@@ -120,7 +119,7 @@ def server_mongo(card='lo'):
 
     if card:
         ip = cmd_ip(card)
-        run('sed -i -e "s/\(bind_ip\s*=\s*\)[0-9\.]*/\\1%s/g" /etc/mongodb.conf' % ip)
+        run('sed -i -e "s/\(bind_ip\s*=\s*\)[0-9\.]*/\\1%s/g" /etc/mongod.conf' % ip)
 
 
     run('chkconfig --level 35 mongod on')
